<?php

namespace Drupal\trash\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\trash\TrashManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Defines a controller to list deleted entities.
 */
class TrashController extends ControllerBase implements ContainerInjectionInterface {

  /**
   * The trash manager.
   *
   * @var \Drupal\trash\TrashManagerInterface
   */
  protected $trashManager;

  /**
   * Constructs a TrashController object.
   *
   * @param \Drupal\trash\TrashManagerInterface $trash_manager
   *   The trash manager.
   */
  public function __construct(TrashManagerInterface $trash_manager) {
    $this->trashManager = $trash_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('trash.manager')
    );
  }

  /**
   * Provides the trash listing page for any entity type.
   *
   * @param string|null $entity_type_id
   *   The ID of the entity type to render.
   *
   * @return array
   *   A render array.
   */
  public function listing(string $entity_type_id = NULL) : array {
    $enabled_entity_types = $this->trashManager->getEnabledEntityTypes();
    if (empty($enabled_entity_types)) {
      throw new NotFoundHttpException();
    }

    $default_entity_type = in_array('node', $enabled_entity_types, TRUE) ? 'node' : reset($enabled_entity_types);
    $entity_type_id = $entity_type_id ?: $default_entity_type;
    if (!in_array($entity_type_id, $enabled_entity_types, TRUE)) {
      throw new NotFoundHttpException();
    }

    $build = $this->trashManager->executeInTrashContext('inactive', function () use ($entity_type_id) {
      return $this->entityTypeManager()->getListBuilder($entity_type_id)->render();
    });
    $build['#cache']['tags'][] = 'config:trash.settings';

    return $build;
  }

}
