<?php

namespace Drupal\trash\EntityQuery;

/**
 * @property string $entityTypeId
 * @property \Drupal\Core\Entity\EntityTypeInterface $entityType
 * @property \Drupal\Core\Database\Query\ConditionInterface $condition
 */
trait QueryTrait {

  public function isDeleted() {
    $this->addMetaData('trash', 'inactive');
    return $this;
  }

  public function isNotDeleted() {
    $this->addMetaData('trash', 'active');
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareTrash() {
    // Do not alter entity revision queries.
    if ($this->allRevisions) {
      return $this;
    }

    /** @var \Drupal\trash\TrashManagerInterface $trash_manager */
    $trash_manager = \Drupal::service('trash.manager');
    if (!$trash_manager->shouldAlterQueries() || !$trash_manager->isEntityTypeEnabled($this->entityType)) {
      return $this;
    }

    $revision_key = $this->entityType->getKey('revision');
    $deleted_key = 'deleted';

    // Skip adding a deleted flag for revisions as well as an explicit filter
    // on deleted, so you can still list deleted content, if needed.
    foreach ($this->condition->conditions() as $condition) {
      // Loading a revision is explicit. So when we try to load one we should do
      // so without a condition on the deleted flag.
      if ($condition['field'] === $revision_key) {
        return $this;
      }
      if ($condition['field'] === $deleted_key) {
        return $this;
      }
    }

    if (!$this->getMetaData('trash')) {
      $this->addMetaData('trash', $trash_manager->getTrashContext());
    }

    if ($this->getMetaData('trash') === 'inactive') {
      $this->exists($deleted_key);
    }
    else {
      $this->notExists($deleted_key);
    }

    return $this;
  }

}
