<?php

namespace Drupal\trash;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderBase;
use Drupal\trash\EntityQuery\Workspaces\QueryFactory as WorkspacesQueryFactory;
use Drupal\trash\EntityQuery\Sql\QueryFactory as SqlQueryFactory;
use Symfony\Component\DependencyInjection\Reference;

class TrashServiceProvider extends ServiceProviderBase {

  /**
   * {@inheritdoc}
   */
  public function alter(ContainerBuilder $container) {
    // @todo Revert to decorating the entity type manager when we can require
    //   Drupal 10.
    if ($container->hasDefinition('entity_type.manager')) {
      $container->getDefinition('entity_type.manager')
        ->setClass(TrashEntityTypeManager::class);
    }

    // We cannot use the module handler as the container is not yet compiled.
    // @see \Drupal\Core\DrupalKernel::compileContainer()
    $modules = $container->getParameter('container.modules');

    if (isset($modules['workspaces'])) {
      $container->getDefinition('entity.query.sql')
        ->setClass(WorkspacesQueryFactory::class)
        ->addArgument(new Reference('workspaces.manager'));
      $container->removeDefinition('workspaces.entity.query.sql');
    }
    else {
      $container->getDefinition('entity.query.sql')
        ->setClass(SqlQueryFactory::class);
    }

    if ($container->hasDefinition('workspaces.association')) {
      $container->register('trash.workspaces.association', TrashWorkspaceAssociation::class)
        ->setPublic(FALSE)
        ->setDecoratedService('workspaces.association', NULL, 100)
        ->addArgument(new Reference('trash.workspaces.association.inner'))
        ->addArgument(new Reference('trash.manager'))
        ->addTag('backend_overridable');
    }
  }

}
