<?php

namespace Drupal\Tests\trash\Kernel;

use Drupal\trash_test\Entity\TrashTest;
use Drupal\views\Tests\ViewResultAssertionTrait;
use Drupal\views\Views;

/**
 * @group trash
 */
class ViewQueryTest extends TrashKernelTestBase {

  use ViewResultAssertionTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['views'];

  public function testQueryWithoutDeletedAccess() {
    $entities = [];

    for ($i = 0; $i < 5; $i++) {
      $entity = TrashTest::create();
      $entity->save();
      $entities[] = $entity;
    }

    // Test whether they appear in the view.
    $view = Views::getView('trash_test_view');
    $view->execute('page_1');
    $this->assertIdenticalResultset($view, [
      ['id' => 1],
      ['id' => 2],
      ['id' => 3],
      ['id' => 4],
      ['id' => 5],
    ], ['id' => 'id']);
    $view->destroy();

    // Delete the first three of them. They should all be individual loadable
    // but not longer accessible via the view.
    for ($i = 0; $i < 3; $i++) {
      $entities[$i]->delete();

      $this->assertNotNull(TrashTest::load($entities[$i]->id()));
    }

    $view = Views::getView('trash_test_view');
    $view->execute('page_1');
    $this->assertIdenticalResultset($view, [
      ['id' => 4],
      ['id' => 5],
    ], ['id' => 'id']);
    $view->destroy();
  }

  public function testQueryWithDeletedAccess() {
    $entities = [];

    for ($i = 0; $i < 5; $i++) {
      $entity = TrashTest::create();
      $entity->save();
      $entities[] = $entity;
    }

    // Test whether they appear in the view.
    $view = Views::getView('trash_test_view');
    $view->execute('page_1');
    $this->assertIdenticalResultset($view, [
      ['id' => 1],
      ['id' => 2],
      ['id' => 3],
      ['id' => 4],
      ['id' => 5],
    ], ['id' => 'id']);
    $view->destroy();

    // Delete the first three of them. They should all be individual loadable
    // but no longer accessible via the view.
    for ($i = 0; $i < 3; $i++) {
      $entities[$i]->delete();
    }

    $view = Views::getView('trash_test_view');
    $view->execute('page_2');
    $this->assertIdenticalResultset($view, [
      ['id' => 4],
      ['id' => 5],
    ], ['id' => 'id']);
    $view->destroy();
  }

}
